<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>FontPreferences</name>
    <message>
        <location filename="../FontPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Widok graficzny</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Fonts</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Czcionki:
Czcionki
Rozmiar czcionki</translatorcomment>
        <translation>Czcionki</translation>
    </message>
</context>
<context>
    <name>GraphicsViewFonts</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+41"/>
        <source>Ruler Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Czcionka linijki:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Snap Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Czcionka etykiety przyciągania:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Czcionka etykiety informacji:</translation>
    </message>
</context>
</TS>
